# Mirage-Core
日本語文章解析エンジン。伝統的な自然言語処理（NLP）とLLMを組み合わせたハイブリッドアーキテクチャを採用しています。

# Tools

A tool to convert other formats (mainly Aozora Bunko) to .MDI

Supported file(text) formats:
- Plain text (.txt)
- Markdown (.md)
- [HTML](./samples/蜃気楼/芥川龍之介-蜃気楼.html)（青空文庫）
- [illusion Markdown](https://github.com/Iktahana/illusions/blob/main/MDI.md) (.imd)

